@@ -69,6 +69,11 @@ sub relay_fetch {
     return $self->relay_data->{$key};
 }
 
+sub is_prefetched {
+    my ($self, $key) = @_;
+    return exists $self->relay_data->{$key};
+}
+
 sub get_column {
     my ($self, $column) = @_;
     return undef unless exists $self->row_data->{$column}; ## no critic
@@ -191,6 +196,10 @@ If not yet cached, call C<relay_fetch>.
 
 Fetch related data, and returns related data.
 
+=head2 C<is_prefetched($name)>
+
+If a pre-fetch has been executed, it return a true value.
+
 =head2 C<get_column($column)>
 
 Returns column data without inflate filters.
